@@ -1887,6 +1887,36 @@ class Norm_from_counts(config.Action_with_prefix):
 
 
 
+GLOG_SCRIPT = r"""
+library(nesoni)
+dgelist <- read.counts(COUNTS, norm.file=NORM_FILE)
+elist <- glog2.rpm.counts(dgelist, GLOG_MODERATION)
+
+write.grouped.table(list(glog2=data.frame(elist$E), Annotation=elist$gene), sprintf("%s.csv",PREFIX),comments=c('#glog2 reads-per-million expression levels'))
+"""
+
+@config.Float_flag('glog_moderation', 
+    'Amount of moderation used in log transformation.'
+    ' See "glog" mode in "test-counts:".'
+    )
+@config.String_flag('norm_file', 'Use normalization produced by "norm-from-counts:".')
+@config.Positional('counts', 'File containing output from "nesoni count:"')
+class Glog(config.Action_with_prefix):
+    prefix = None
+    glog_moderation = 5.0
+    norm_file = None
+    counts = None
+
+    def run(self):
+        run_script(GLOG_SCRIPT,
+            PREFIX=self.prefix,
+            GLOG_MODERATION=self.glog_moderation,
+            NORM_FILE=self.norm_file,
+            COUNTS=self.counts,
+            )
+
+
+
 NMF_SCRIPT = """
 
 library(nesoni)
